X-Original-To: pgsql-performance-postgresql.org@localhost.postgresql.org Received: from localhost (mx1.hub.org [200.46.208.251]) by postgresql.org (Postfix) with ESMTP id C51559F9B01 for ; Thu, 25 May 2006 18:11:46 -0300 (ADT) Received: from postgresql.org ([200.46.204.71]) by localhost (mx1.hub.org [200.46.208.251]) (amavisd-new, port 10024) with ESMTP id 35348-04 for ; Thu, 25 May 2006 18:11:41 -0300 (ADT) X-Greylist: from auto-whitelisted by SQLgrey- Received: from sss.pgh.pa.us (sss.pgh.pa.us [66.207.139.130]) by postgresql.org (Postfix) with ESMTP id AD4739F94EA for ; Thu, 25 May 2006 18:11:41 -0300 (ADT) Received: from sss2.sss.pgh.pa.us (tgl@localhost [127.0.0.1]) by sss.pgh.pa.us (8.13.6/8.13.6) with ESMTP id k4PLBbew016120; Thu, 25 May 2006 17:11:38 -0400 (EDT) To: "Merlin Moncure" , "Postgresql Performance" Subject: Re: is it possible to make this faster? In-reply-to: <15919.1148590347@sss.pgh.pa.us> References: <15919.1148590347@sss.pgh.pa.us> Comments: In-reply-to Tom Lane message dated "Thu, 25 May 2006 16:52:27 -0400" Date: Thu, 25 May 2006 17:11:37 -0400 Message-ID: <16119.1148591497@sss.pgh.pa.us> From: Tom Lane X-Virus-Scanned: Maia Mailguard 1.0.1 X-Archive-Number: 200605/479 X-Sequence-Number: 19266 Tom Lane writes: > "Merlin Moncure" writes: >> recent versions of mysql do much better, returning same set in < 20ms. > Well, since they don't do MVCC they can answer this query from the > index without going to the heap at all. But that still seems remarkably > fast for something that has to grovel through 300k index entries. Are you sure you measured that right? I tried to duplicate this using mysql 5.0.21, and I see runtimes of 0.45 sec without an index and 0.15 sec with. This compares to psql times around 0.175 sec. Doesn't look to me like we're hurting all that badly, even without using the index. regards, tom lane